@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2006 Jelmer Vernooij <jelmer@samba.org>
+# Copyright (C) 2005-2006 Jelmer Vernooij <jelmer@jelmer.uk>
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -12,21 +12,15 @@
 
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 """Subversion delta operations."""
 
-__author__ = "Jelmer Vernooij <jelmer@samba.org>"
+__author__ = "Jelmer Vernooij <jelmer@jelmer.uk>"
 __docformat__ = "restructuredText"
 
-import sys
-
-if sys.version_info < (2, 5):
-    import md5 as _mod_md5
-    md5 = _mod_md5.new
-else:
-    from hashlib import (
-        md5,
-        )
+from hashlib import (
+    md5,
+    )
 
 
 TXDELTA_SOURCE = 0
@@ -38,8 +32,19 @@ MAX_ENCODED_INT_LEN = 10
 
 DELTA_WINDOW_SIZE = 102400
 
-def apply_txdelta_window(sbuf, window):
-    (sview_offset, sview_len, tview_len, src_ops, ops, new_data) = window
+def apply_txdelta_window(sbuf,
+            (sview_offset, sview_len, tview_len, src_ops, ops, new_data)):
+    """Apply a txdelta window to a buffer.
+
+    :param sbuf: Source buffer (as bytestring)
+    :param sview_offset: Offset of the source view
+    :param sview_len: Length of the source view
+    :param tview_len: Target view length
+    :param src_ops: Operations to apply to sview
+    :param ops: Ops to apply
+    :param new_data: Buffer with possible new data
+    :return: Target buffer
+    """
     sview = sbuf[sview_offset:sview_offset+sview_len]
     tview = txdelta_apply_ops(src_ops, ops, new_data, sview)
     if len(tview) != tview_len:
@@ -202,6 +207,11 @@ def unpack_svndiff_instruction(text):
 SVNDIFF0_HEADER = "SVN\0"
 
 def pack_svndiff0_window(window):
+    """Pack an individual window using svndiff0.
+
+    :param window: Window to pack
+    :return: Packed diff (as bytestring)
+    """
     (sview_offset, sview_len, tview_len, src_ops, ops, new_data) = window
     ret = [encode_length(sview_offset) + \
            encode_length(sview_len) + \
